/* 
  Version.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  16-OCT-1996

*/

#import <objectbase/SwarmObject.h>

@interface Version: SwarmObject

+(char *) getVersionString;
+(int) getMajorVersion;
+(int) getMinorVersion;
+(int) getPatchVersion;

+(void) printCopyright;

@end
